//******************************************************************************
// Projeto - TESTE_DS1620 - testa termomtro digital Dallas
// Desenvolvido por Mrcio Jos Soares
//
// Arquivo - teste_DS1620.h - configuraes, definies e variveis globais
//******************************************************************************

//******************************************************************************
// Arquivos includos neste mdulo
//******************************************************************************
#include <16F628.h>

//******************************************************************************
// Configuraes para o microcontrolador PIC16F628
//******************************************************************************
#use delay(clock=4000000,RESTART_WDT)
#priority timer0, timer1, RDA

//******************************************************************************
// Configurao dos fuses do microcontrolador PIC16F628
//******************************************************************************
#fuses INTRC_IO,PUT,WDT,NOBROWNOUT,NOMCLR,NOLVP,NOCPD
//INTRC	      Clock interno
//PUT          Ativa tempo de inicializao
//WDT		      Ativa Watch Dog Timer
//NOBROWNOUT	No usa brownout reset
//NOMCLR		   Pino Master Clear usado como I/O
//NOLVP		   No usa baixa voltagem para programao, pino B3 usado como I/O
//NOCPD		   No protege EEPROM

//******************************************************************************
// Configurao da comunicao serial do PIC16F628
//******************************************************************************
#use rs232(baud=9600,parity=N,xmit=PIN_B2,rcv=PIN_B1,bits=8)

//******************************************************************************
// Definies para o mdulo - teste_DS1620
//******************************************************************************
#locate rxreg     = 0x1a         //endereo do registrador p/ byte recebido

#define  JUMPER   PIN_A0         //pino do jumper
#define  LED      PIN_A1         //pino do LED
#define  RST      PIN_B0         //RST do DS1620
#define  CLK      PIN_B3         //CLK do DS1620
#define  DADOS    PIN_A2         //DO do DS1620

//******************************************************************************
// Definies para o DS1620
//******************************************************************************
#define ESCRCONF  0x0C           //protocolo para escrita
#define LECONF    0xAC           //protocolo para leitura
#define DS_CPU    0x02           //bit de config.: termometro no modo serial
#define DS_NCPU   0x00           //bit de config.: termometro no modo "standalone"
#define DS_ONE    0x01           //bit de config.: uma converso por vez, quando ligado
#define DS_CONT   0x00           //bit de config.: converso contnua, quando ligado

#define DS_INIT   0xEE           //protocolo para iniciar a converso
#define DS_STOP   0x22           //protocolo para parar a converso
#define DS_TEMP   0xAA           //protocolo para ler a temperatura

#define DS_RHI    0xA1           //protocolo para ler "High-Temperature Setting"
#define DS_WHI    0x01           //protocolo para escrever "High-Temperature Setting"
#define DS_RLO    0xA2           //protocolo para ler "Low-Temperature Setting"
#define DS_WLO    0x02           //protocolo para escrever "Low-Temperature Setting"

//******************************************************************************
// Variveis Globais do mdulo - teste_adc0831
//******************************************************************************
unsigned char convert;           //varivel para selecionar tipo de converso
                                 //Celsius ou Fahrenheit
unsigned char sinal;             //sinal (+ ou -) a ser enviado pela serial

int16 dado_rec;                  //varivel para troca e recepo

boolean conf1=false;             //varivel para verificar se DS1620 j foi
                                 //configurado

